#include <vector>
#include <algorithm>
#include <set>

#include<vcg/simplex/vertex/base.h>
#include<vcg/simplex/face/base.h>
#include<vcg/simplex/face/component_ocf.h>
#include<vcg/complex/trimesh/base.h>

#include<vcg/complex/trimesh/update/flag.h>
#include<vcg/simplex/face/pos.h>
#include<vcg/complex/trimesh/update/topology.h>

#include<wrap/io_trimesh/import_ply.h>
#include<wrap/io_trimesh/export_ply.h>

using namespace vcg;

class MyEdge;    // dummy prototype never used
class MyFace;
class MyVertex;

class MyVertex  : public VertexSimp2< MyVertex, MyEdge, MyFace, vertex::Coord3f, vertex::BitFlags, vertex::Normal3f, vertex::Color4b >{};
class MyFace    : public FaceSimp2  < MyVertex, MyEdge, MyFace, face::VertexRef, face::Normal3f, face::BitFlags, face::FFAdj, face::Color4b> {};
class MyMesh : public tri::TriMesh< std::vector<MyVertex>, std::vector<MyFace > >{};


int main(int argc,char **argv ){

    MyMesh m;
    if(argc==1) return 0;

	if(tri::io::ImporterPLY<MyMesh>::Open(m,argv[1])!=0)
		{
      printf("Error reading file  %s\n",argv[1]);
			exit(0);
		}
		
    printf("vn %i fn %i\n",m.vn, m.fn);

    MyMesh::VertexIterator vi;
    MyMesh::FaceIterator fi;
    vcg::tri::UpdateTopology<MyMesh>::FaceFace(m);


    MyMesh::FacePointer f0,f1;
    int  e0,e1; // lato condiviso

    assert(f0->FFp(e0)==f1);
    assert(f1->FFp(e1)==f0);

    MyMesh::VertexPointer ve0 = f0->V0(e0);
    MyMesh::VertexPointer ve1 = f0->V1(e0);

    assert( (ve0 == f1->V0(e1)) ||(ve0 == f1->V1(e1)) );
    assert( (ve1 == f1->V0(e1)) ||(ve1 == f1->V1(e1)) );

    assert(ve0 != ve1);

    MyMesh::VertexPointer vf0 = f0->V2(e0);
    MyMesh::VertexPointer vf1 = f1->V2(e1);

    assert(vf0 != vf1);

    f0->V0(e0) = vf1;
    f0->V1(e0) = vf0;
    f0->V2(e0) = ve0;

    f1->V0(e1) = vf0;
    f1->V1(e1) = vf1;
    f1->V2(e1) = ve1;




  return 0;
}

